@@ -5,11 +5,13 @@ OC.L10N.register(
     "Rename" : "Renombrar",
     "Copy link" : "Copiar enlace",
     "Move" : "Mover",
+    "Link copied to clipboard" : "Enlace copiado al portapapeles",
     "Select all" : "Seleccionar todo",
     "Go back" : "Regresar",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva",
     "Search" : "Buscar",
+    "Empty trash bin" : "Vaciar la papelera",
     "Rename folder" : "Renombrar carpeta",
     "Choose folder" : "Elegir carpeta",
     "Submit" : "Enviar",
