@@ -6,31 +6,38 @@ OC.L10N.register(
     "Unsupported file type for import" : "Tipo de archivo no soportado para importar",
     "Details" : "Detalles",
     "Rename" : "Renombrar",
+    "Copy link" : "Copiar liga",
     "Move" : "Mover",
-    "Delete" : "Borrar",
     "Select all" : "Seleccionar todo",
+    "Go back" : "Regresar",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva",
+    "Search" : "Buscar",
+    "Empty trash bin" : "Vaciar papelera de reciclaje",
+    "Add a bookmark" : "Agregar un marcador",
+    "Choose folder" : "Seleccioanr carpeta",
     "Submit" : "Enviar",
     "Cancel" : "Cancelar",
     "Recent" : "Reciente",
-    "Import" : "Importar",
-    "Export" : "Exportar",
+    "Shared with you" : "Compartido con usted",
+    "Files" : "Archivos",
+    "Delete" : "Borrar",
+    "Settings" : "Configuraciones ",
     "Bookmarklet" : "Marcador a código ",
-    "Clear data" : "Borrar datos",
+    "Need help?" : "¿Necesitas ayuda?",
     "Title" : "Título",
     "Link" : "Liga",
     "Tags" : "Etiquetas",
     "Notes" : "Notas",
+    "Download file" : "Descargar archivo",
     "Owner" : "Dueño",
     "Sharing" : "Compartiendo",
     "Share link" : "Compartir liga",
-    "Copy link" : "Copiar liga",
     "Allow editing" : "Permitir edición",
+    "Allow resharing" : "Permitir volver a compartir",
     "Privacy" : "Privacidad",
-    "Add a bookmark" : "Agregar un marcador",
     "This URL is already bookmarked! Overwrite?" : "¡Esta URL ya está marcada! ¿Quieres sobreescribirlo?",
     "Folder" : "Carpeta",
     "Save" : "Guardar"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
