@@ -8,27 +8,27 @@ OC.L10N.register(
     "Rename" : "Renombrar",
     "Copy link" : "Copiar liga",
     "Move" : "Mover",
-    "Delete" : "Borrar",
     "Select all" : "Seleccionar todo",
     "Go back" : "Regresar",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva",
+    "Search" : "Buscar",
     "Add a bookmark" : "Agregar un marcador",
-    "Delete folder" : "Borrar carpeta",
     "Choose folder" : "Seleccioanr carpeta",
     "Submit" : "Enviar",
     "Cancel" : "Cancelar",
     "Recent" : "Reciente",
     "Shared with you" : "Compartido con usted",
     "Files" : "Archivos",
-    "Import" : "Importar",
-    "Export" : "Exportar",
+    "Delete" : "Borrar",
+    "Settings" : "Configuraciones ",
     "Bookmarklet" : "Marcador a código ",
+    "Need help?" : "¿Necesitas ayuda?",
     "Title" : "Título",
     "Link" : "Liga",
     "Tags" : "Etiquetas",
     "Notes" : "Notas",
-    "Open file" : "Abrir archivo",
+    "Download file" : "Descargar archivo",
     "Owner" : "Dueño",
     "Sharing" : "Compartiendo",
     "Share link" : "Compartir liga",
@@ -39,4 +39,4 @@ OC.L10N.register(
     "Folder" : "Carpeta",
     "Save" : "Guardar"
 },
-"nplurals=2; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
