@@ -5,6 +5,7 @@ OC.L10N.register(
     "Rename" : "Преименувај",
     "Copy link" : "Копирај линк",
     "Move" : "Премести",
+    "Link copied to clipboard" : "Линкот е копиран во клипборд",
     "Delete selection" : "Избриши ги селектираните",
     "Select all" : "Избери се",
     "Go back" : "Назад",
@@ -12,6 +13,7 @@ OC.L10N.register(
     "New" : "Ново",
     "New folder" : "Нова папка",
     "Search" : "Барај",
+    "Empty trash bin" : "Испразни ја корпата со отпадоци",
     "RSS feed copied" : "RSS канал копиран",
     "Rename folder" : "Преименувај папка",
     "Submit" : "Испрати",
