@@ -78,6 +78,7 @@ OC.L10N.register(
     "Copy RSS Feed of current view" : "Skopírovať RSS kanál aktuálneho zobrazenia",
     "The RSS feed requires authentication with your Nextcloud credentials" : "Informačný kanál RSS vyžaduje autentizáciu pomocou vašich prihlasovacích údajov Nextcloud",
     "Search" : "Hľadať",
+    "Empty trash bin" : "Vyprázdniť kôš",
     "Sort by created date" : "Zoradiť podľa dátumu vytvorenia",
     "Sort by last modified" : "Zoradiť podľa dátumu poslednej zmeny",
     "Sort by title" : "Zoradiť podľa nadpisu",
@@ -132,6 +133,7 @@ OC.L10N.register(
     "No broken links" : "Žiadne poškodené odkazy",
     "No shared folders" : "Žiadne zdieľané priečinky",
     "No duplicated bookmarks" : "Žiadne duplikovanéq záložky",
+    "You haven't deleted anything yet." : "Zatiaľ ste nič neodstránili.",
     "No bookmarks here" : "Žiadne záložky",
     "Add bookmarks manually or import bookmarks from a HTML file." : "Pridajte záložky ručne alebo ich importujte z HTML súboru.",
     "Bookmarks settings" : "Nastavenia záložiek",
