@@ -58,7 +58,7 @@ OC.L10N.register(
     "This content is being downloaded for offline use. Please check back later." : "正在下載此內容以供離線使用。請稍後再檢查。",
     "Bookmarked {time} ago" : "{time} 前加入書籤",
     "Bookmarked on {date}" : "於 {date} 加入書籤",
-    "These are your deleted items." : "這些是您刪除的項目。",
+    "These are your deleted items. Items will be deleted permanently after two months." : "這是您已刪除的項目。項目將在兩個月後永久刪除。",
     "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "網絡上的檔案（如照片或 PDF）的書籤將自動保存到您的 Nextcloud 檔案中，因此即使連結離線，您也仍然可以找到它們。",
     "Searching in the current folder only." : "僅在目前資料夾中搜尋。",
     "Repeat search in all folders" : "在所有資料夾中重複搜尋",
@@ -87,6 +87,7 @@ OC.L10N.register(
     "Copy RSS Feed of current view" : "複製當前視圖的RSS Feed",
     "The RSS feed requires authentication with your Nextcloud credentials" : "RSS feed 需要使用您的 Nextcloud 身份驗證進行驗證",
     "Search" : "搜尋",
+    "Empty trash bin" : "清空回收桶",
     "Sort by created date" : "按創建日期排序",
     "Sort by last modified" : "按修改日期排序",
     "Sort by title" : "按標題排序",
