@@ -38,6 +38,8 @@ OC.L10N.register(
     "Create bookmark" : "建立書籤",
     "Takes a link and adds it to your collection of bookmarks." : "取得連結並新增到您的書籤集合中。",
     "Bookmarks Backups" : "書籤備份",
+    "Collect and manage bookmarks, synced with all your devices" : "蒐集並管理書籤，與您所有的裝置同步",
+    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users and via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 將書籤分類到資料夾中\n- 🏷 新增標籤與個人筆記\n- ☠ 尋找損壞與重複的連結\n- 📲 與您所有瀏覽器與裝置同步\n- 📔 若您的連結被取消發佈，您還是可以閱讀它們的封存版本\n- 🔍 對網站內容進行全文搜尋\n- 👪 Share bookmarks with other users and via public links\n- ⚛ 產生您收藏的 RSS 摘要\n- 📈 關於您存取哪些連結的頻率的統計資訊\n- 🔒 自動備份您的書籤\n- 💼 用於經常造訪與最近新增連結的內建儀表板小工具\n\n系統需求：\n - PHP 擴充套件：\n   - intl: *\n   - mbstring: *\n - 若使用 MySQL，則至少需要 v8.0",
     "Enter new title" : "輸入新的標題",
     "Select bookmark" : "選擇書籤",
     "You have never clicked this link" : "您從未點擊過此連結",
@@ -56,7 +58,7 @@ OC.L10N.register(
     "This content is being downloaded for offline use. Please check back later." : "此內容已下載供離線使用。請稍後再檢查。",
     "Bookmarked {time} ago" : "{time} 前加入書籤",
     "Bookmarked on {date}" : "於 {date} 加入書籤",
-    "These are your deleted items." : "這些是您刪除的項目。",
+    "These are your deleted items. Items will be deleted permanently after two months." : "這是您已刪除的項目。項目將會在兩個月後永久刪除。",
     "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "網路上的檔案（如照片或 PDF 等）的書籤將會自動儲存到您的 Nextcloud 檔案中，因此即便連結離線，您也仍然可以找到它們。",
     "Searching in the current folder only." : "僅在目前資料夾中搜尋。",
     "Repeat search in all folders" : "在所有資料夾中重複搜尋",
@@ -85,6 +87,7 @@ OC.L10N.register(
     "Copy RSS Feed of current view" : "複製目前檢視的 RSS Feed",
     "The RSS feed requires authentication with your Nextcloud credentials" : "RSS feed 需要使用您的 Nextcloud 憑證驗證",
     "Search" : "搜尋",
+    "Empty trash bin" : "清空回收桶",
     "Sort by created date" : "按建立日期排序",
     "Sort by last modified" : "按最後修改時間排序",
     "Sort by title" : "按標題排序",
