@@ -1,4 +1,9 @@
 <?php
+/*
+ * Copyright (c) 2020-2024. The Nextcloud Bookmarks contributors.
+ *
+ * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
+ */
 
 namespace OCA\Bookmarks\Service;
 
@@ -7,6 +12,7 @@ use Rowbot\URL\Exception\TypeError;
 use Rowbot\URL\URL;
 
 class UrlNormalizer {
+	/** @var array<string, string>  */
 	private $cache = [];
 
 	public function __construct() {
@@ -17,7 +23,7 @@ class UrlNormalizer {
 	 * @return string
 	 * @throws UrlParseError
 	 */
-	public function normalize($urlString) {
+	public function normalize(string $urlString): string {
 		if (isset($this->cache[$urlString])) {
 			return $this->cache[$urlString];
 		}
